@@ -3,8 +3,9 @@ Main interface for codedeploy service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codedeploy import (
+    from mypy_boto3_codedeploy import (
         Client,
         CodeDeployClient,
         DeploymentSuccessfulWaiter,
@@ -17,7 +18,7 @@ Usage::
         ListDeploymentsPaginator,
         ListGitHubAccountTokenNamesPaginator,
         ListOnPremisesInstancesPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -35,6 +36,7 @@ Usage::
     list_deployments_paginator: ListDeploymentsPaginator = client.get_paginator("list_deployments")
     list_git_hub_account_token_names_paginator: ListGitHubAccountTokenNamesPaginator = client.get_paginator("list_git_hub_account_token_names")
     list_on_premises_instances_paginator: ListOnPremisesInstancesPaginator = client.get_paginator("list_on_premises_instances")
+    ```
 """
 from mypy_boto3_codedeploy.client import CodeDeployClient as Client, CodeDeployClient
 from mypy_boto3_codedeploy.paginator import (
