@@ -3,13 +3,15 @@ Main interface for codedeploy service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codedeploy import CodeDeployClient
+    from mypy_boto3_codedeploy import CodeDeployClient
 
     session = boto3.Session()
 
     client: CodeDeployClient = boto3.client("codedeploy")
     session_client: CodeDeployClient = session.client("codedeploy")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
