@@ -3,8 +3,11 @@ Main interface for codedeploy service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codedeploy import (
+
+    from mypy_boto3_codedeploy import CodeDeployClient
+    from mypy_boto3_codedeploy import (
         ListApplicationRevisionsPaginator,
         ListApplicationsPaginator,
         ListDeploymentConfigsPaginator,
@@ -27,6 +30,7 @@ Usage::
     list_deployments_paginator: ListDeploymentsPaginator = client.get_paginator("list_deployments")
     list_git_hub_account_token_names_paginator: ListGitHubAccountTokenNamesPaginator = client.get_paginator("list_git_hub_account_token_names")
     list_on_premises_instances_paginator: ListOnPremisesInstancesPaginator = client.get_paginator("list_on_premises_instances")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
