@@ -3,14 +3,18 @@ Main interface for codedeploy service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codedeploy import (
+
+    from mypy_boto3_codedeploy import CodeDeployClient
+    from mypy_boto3_codedeploy import (
         DeploymentSuccessfulWaiter,
     )
 
     client: CodeDeployClient = boto3.client("codedeploy")
 
     deployment_successful_waiter: DeploymentSuccessfulWaiter = client.get_waiter("deployment_successful")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import TYPE_CHECKING
